function write_value(file, value)
  if string.find(value, '%^') then
    file:write('[[');
    local first = true;
    for str in string.gmatch(value, "([^^]*)") do
      if str ~= '' then
        if not first then
          file:write('^');
        end;
        first = false;
        file:write(str)
      end;
    end
    file:write(']]')
  elseif string.find(value, '"') then
    local value = string.gsub(value, "'", "\\'");
    file:write(string.format("'%s'", value))
  elseif string.find(value, '\'') then
    local value = string.gsub(value, '"', '\\"');
    file:write(string.format('"%s"', value))
  else
    file:write(string.format("'%s'", value))
  end;
end;

function declare(tab)
    local trs = {
      en = io.open('translation/en.lua', 'w');
      ru = io.open('translation/ru.lua', 'w');
      eo = io.open('translation/eo.lua', 'w');
    }
    
    for k, v in pairs(trs) do
      v:write('declare {\n');
    end
    
    for _, locale_domain in ipairs({'common_locale', 'main_locale', 'menu_locale', 'terminal_locale', 'tutorial_locale', 'forest_locale', 'solarscale_locale', 'tower_locale', 'computer_locale', 'parts_locale', 'note_locale', 'ending_locale'}) do
      local translations = tab[locale_domain];
      
      for k, v in pairs(trs) do
        v:write(string.format('  %s = {\n', locale_domain));
      end
      
      local keys = {};
      
      for key, _ in pairs(translations) do
        keys[#keys + 1] = key;
      end;
      
      table.sort(keys);
      
      for _, key in ipairs(keys) do
        local values = translations[key]
        for k, v in pairs(trs) do
          v:write(string.format('    %s = ', key));
          write_value(v, values[k] or values['ru']);
          v:write(',\n');
        end;
      end;
      
      for k, v in pairs(trs) do
        v:write('  },\n');
      end
    
    end;
    
    for k, v in pairs(trs) do
      v:write('}\n');
      v:close();
    end
end

dofile "translation.lua"